@@ -1,6 +1,6 @@
 /* horst - Highly Optimized Radio Scanning Tool
  *
- * Copyright (C) 2005-2011 Bruno Randolf (br1@einfach.org)
+ * Copyright (C) 2005-2014 Bruno Randolf (br1@einfach.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,8 +20,10 @@
 #ifndef _CAPTURE_H_
 #define _CAPTURE_H_
 
+#include <stddef.h>
+
 int
-open_packet_socket(char* devname, size_t bufsize, int recv_buffer_size);
+open_packet_socket(char* devname, int recv_buffer_size);
 
 int
 recv_packet(int fd, unsigned char* buffer, size_t bufsize);
@@ -30,6 +32,6 @@ void
 close_packet_socket(int fd, char* ifname);
 
 int
-device_get_arptype(int fd, char* ifname);
+device_get_hwinfo(int fd, char* ifname, unsigned char* mac);
 
 #endif // _CAPTURE_H_
