@@ -105,7 +105,7 @@ printlog(const char *fmt, ...)
 	vsnprintf(&buf[1], 127, fmt, ap);
 	va_end(ap);
 
-	if (conf.quiet || DO_DEBUG || !conf.display_initialized)
+	if (conf.quiet || conf.debug || !conf.display_initialized)
 		printf("%s\n", &buf[1]);
 	else {
 		/* fix up string for display log */
@@ -122,7 +122,6 @@ update_history(struct packet_info* p)
 		return;
 
 	hist.signal[hist.index] = p->phy_signal;
-	hist.noise[hist.index] = p->phy_noise;
 	hist.rate[hist.index] = p->phy_rate;
 	hist.type[hist.index] = (p->phy_flags & PHY_FLAG_BADFCS) ? 1 : p->wlan_type;
 	hist.retry[hist.index] = p->wlan_retry;
@@ -173,7 +172,6 @@ update_spectrum(struct packet_info* p, struct node_info* n)
 
 	chan = &spectrum[p->pkt_chan_idx];
 	chan->signal = p->phy_signal;
-	chan->noise = p->phy_noise;
 	chan->packets++;
 	chan->bytes += p->wlan_len;
 	chan->durations += p->pkt_duration;
@@ -232,7 +230,7 @@ write_to_file(struct packet_info* p)
 	fprintf(DF, "%s, ", ether_sprintf(p->wlan_dst));
 	fprintf(DF, "%s, ", ether_sprintf(p->wlan_bssid));
 	fprintf(DF, "%x, %d, %d, %d, %d, %d, %d, ",
-		p->pkt_types, p->phy_signal, p->phy_noise, p->phy_snr,
+		p->pkt_types, p->phy_signal, 0, 0,
 		p->wlan_len, p->phy_rate, p->phy_freq);
 	fprintf(DF, "%016llx, ", (unsigned long long)p->wlan_tsf);
 	fprintf(DF, "%s, %d, %d, %d, %d, %d, ",
@@ -298,7 +296,7 @@ handle_packet(struct packet_info* p)
 
 	/* filter on server side only */
 	if (!conf.serveraddr && filter_packet(p)) {
-		if (!conf.quiet && !conf.paused && !DO_DEBUG)
+		if (!conf.quiet && !conf.paused && !conf.debug)
 			update_display_clock();
 		return;
 	}
@@ -329,10 +327,6 @@ handle_packet(struct packet_info* p)
 	if (p->wlan_channel == 0 && p->pkt_chan_idx >= 0)
 		p->wlan_channel = channel_get_chan_from_idx(p->pkt_chan_idx);
 
-	/* detect if noise reading is present or not */
-	if (!conf.have_noise && p->phy_noise)
-		conf.have_noise = 1;
-
 	/* if current channel is unknown (this is a mac80211 bug), guess it from
 	 * the packet */
 	if (conf.channel_idx < 0 && p->pkt_chan_idx >= 0)
@@ -360,10 +354,8 @@ handle_packet(struct packet_info* p)
 	update_spectrum(p, n);
 	update_essids(p, n);
 
-#if !DO_DEBUG
-	if (!conf.quiet)
+	if (!conf.quiet && !conf.debug)
 		update_display(p);
-#endif
 }
 
 
@@ -373,10 +365,15 @@ local_receive_packet(int fd, unsigned char* buffer, size_t bufsize)
 	int len;
 	struct packet_info p;
 
+	DEBUG("\n===============================================================================\n");
+
 	len = recv_packet(fd, buffer, bufsize);
 
 #if DO_DEBUG
-	dump_packet(buffer, len);
+	if (conf.debug) {
+		dump_packet(buffer, len);
+		DEBUG("\n");
+	}
 #endif
 	memset(&p, 0, sizeof(p));
 
@@ -397,7 +394,7 @@ receive_any(void)
 	FD_ZERO(&read_fds);
 	FD_ZERO(&write_fds);
 	FD_ZERO(&excpt_fds);
-	if (!conf.quiet && !DO_DEBUG)
+	if (!conf.quiet && !conf.debug)
 		FD_SET(0, &read_fds);
 	FD_SET(mon, &read_fds);
 	if (srv_fd != -1)
@@ -417,7 +414,7 @@ receive_any(void)
 	if (ret == -1 && errno == EINTR) /* interrupted */
 		return;
 	if (ret == 0) { /* timeout */
-		if (!conf.quiet && !DO_DEBUG)
+		if (!conf.quiet && !conf.debug)
 			update_display_clock();
 		return;
 	}
@@ -425,7 +422,7 @@ receive_any(void)
 		err(1, "select()");
 
 	/* stdin */
-	if (FD_ISSET(0, &read_fds) && !conf.quiet && !DO_DEBUG)
+	if (FD_ISSET(0, &read_fds) && !conf.quiet && !conf.debug)
 		handle_user_input();
 
 	/* local packet or client */
@@ -500,12 +497,11 @@ finish_all(void)
 	if (conf.allow_control)
 		control_finish();
 
-#if !DO_DEBUG
-	net_finish();
+	if (!conf.debug)
+		net_finish();
 
-	if (!conf.quiet)
+	if (!conf.quiet && !conf.debug)
 		finish_display();
-#endif
 }
 
 
@@ -536,7 +532,7 @@ get_options(int argc, char** argv)
 	int c;
 	static int n;
 
-	while((c = getopt(argc, argv, "hqsCi:t:c:p:e:f:d:o:b:X::x:m:u:U:a:")) > 0) {
+	while((c = getopt(argc, argv, "hqDsCi:t:c:p:e:f:d:o:b:X::x:m:u:a:")) > 0) {
 		switch (c) {
 		case 'p':
 			conf.port = optarg;
@@ -544,6 +540,15 @@ get_options(int argc, char** argv)
 		case 'q':
 			conf.quiet = 1;
 			break;
+		case 'D':
+#if DO_DEBUG
+			conf.debug = 1;
+#else
+			printf("Please compile with DEBUG=1 to use the -D option!\n");
+			exit(1);
+#endif
+			break;
+
 		case 'i':
 			conf.ifname = optarg;
 			break;
@@ -576,6 +581,9 @@ get_options(int argc, char** argv)
 		case 'C':
 			conf.allow_client = 1;
 			break;
+		case 'u':
+			conf.channel_max = atoi(optarg);
+			break;
 		case 'X':
 			if (optarg != NULL)
 				conf.control_pipe = optarg;
@@ -653,20 +661,24 @@ get_options(int argc, char** argv)
 			break;
 		case 'h':
 		default:
-			printf("\nUsage: %s [-h] [-q] [-i interface] [-t sec] [-d ms] [-b bytes]\n"
-				"\t\t[-s] [-C] [-c IP] [-p port] [-o file] [-X[name]] [-x command]\n"
+			printf("\nUsage: %s [-h] [-q] [-D ] [-i interface] [-t sec] [-d ms] [-b bytes]\n"
+				"\t\t[-s] [-u] [-C] [-c IP] [-p port] [-o file] [-X[name]] [-x command]\n"
 				"\t\t[-e MAC] [-f PKT_NAME] [-m MODE]\n\n"
 
 				"General Options: Description (default value)\n"
 				"  -h\t\tHelp\n"
 				"  -q\t\tQuiet, no output\n"
+#if DO_DEBUG
+				"  -D\t\tShow lots of debug output, no UI\n"
+#endif
 				"  -i <intf>\tInterface name (wlan0)\n"
 				"  -t <sec>\tNode timeout in seconds (60)\n"
 				"  -d <ms>\tDisplay update interval in ms (100)\n"
 				"  -b <bytes>\tReceive buffer size in bytes (not set)\n"
 
 				"\nFeature Options:\n"
-				"  -s\t\t(Poor mans) Spectrum analyzer mode\n\n"
+				"  -s\t\t(Poor mans) Spectrum analyzer mode\n"
+				"  -u\t\tUpper channel limit\n\n"
 
 				"  -C\t\tAllow client connection, server mode (off)\n"
 				"  -c <IP>\tConnect to server with <IP>, client mode (off)\n"
@@ -750,7 +762,7 @@ main(int argc, char** argv)
 		init_spectrum();
 	}
 
-	if (!conf.quiet && !DO_DEBUG)
+	if (!conf.quiet && !conf.debug)
 		init_display();
 
 	if (conf.dumpfile != NULL)
@@ -769,7 +781,7 @@ main(int argc, char** argv)
 			if (channel_auto_change()) {
 				net_send_channel_config();
 				update_spectrum_durations();
-				if (!conf.quiet && !DO_DEBUG)
+				if (!conf.quiet && !conf.debug)
 					update_display(NULL);
 			}
 		}
