@@ -28,12 +28,18 @@
 #include "channel.h"
 #include "wlan80211.h"
 
-#define VERSION "4.0"
+#define VERSION "4.2"
 
 #ifndef DO_DEBUG
 #define DO_DEBUG 0
 #endif
 
+#if DO_DEBUG
+#define DEBUG(...) do { if (conf.debug) printf(__VA_ARGS__); } while (0)
+#else
+#define DEBUG(...)
+#endif
+
 #define MAC_LEN			6
 
 #define MAX_HISTORY		255
@@ -113,8 +119,6 @@ struct packet_info {
 
 	/* wlan phy (from radiotap) */
 	int			phy_signal;	/* signal strength (usually dBm) */
-	int			phy_noise;	/* noise level (usually dBm) */
-	unsigned int		phy_snr;	/* signal to noise ratio */
 	unsigned int		phy_rate;	/* physical rate * 10 (=in 100kbps) */
 	unsigned char		phy_rate_idx;	/* MCS index */
 	unsigned char		phy_rate_flags;	/* MCS flags */
@@ -176,9 +180,6 @@ struct node_info {
 	unsigned int		pkt_count;	/* nr of packets seen */
 
 	/* wlan phy (from radiotap) */
-	unsigned int		phy_snr_min;
-	unsigned int		phy_snr_max;
-	struct ewma		phy_snr_avg;
 	int			phy_sig_max;
 	struct ewma		phy_sig_avg;
 	unsigned long		phy_sig_sum;
@@ -232,7 +233,6 @@ extern struct essid_meta_info essids;
 
 struct history {
 	int			signal[MAX_HISTORY];
-	int			noise[MAX_HISTORY];
 	int			rate[MAX_HISTORY];
 	unsigned int		type[MAX_HISTORY];
 	unsigned int		retry[MAX_HISTORY];
@@ -265,7 +265,6 @@ extern struct statistics stats;
 struct channel_info {
 	int			signal;
 	struct ewma		signal_avg;
-	int			noise;
 	unsigned long		packets;
 	unsigned long		bytes;
 	unsigned long		durations;
@@ -312,9 +311,9 @@ struct config {
 				do_change_channel:1,
 				allow_client:1,
 				allow_control:1,
+				debug:1,
 	/* this isn't exactly config, but wtf... */
 				do_macfilter:1,
-				have_noise:1,
 				display_initialized:1;
 	int			arphrd; // the device ARP type
 	unsigned char		my_mac_addr[MAC_LEN];
