@@ -1,6 +1,6 @@
 /* horst - Highly Optimized Radio Scanning Tool
  *
- * Copyright (C) 2005-2011 Bruno Randolf (br1@einfach.org)
+ * Copyright (C) 2005-2014 Bruno Randolf (br1@einfach.org)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
 #ifndef _WEXT_H_
 #define _WEXT_H_
 
-#include "main.h"
+#include "channel.h"
 
 int
 wext_set_freq(int fd, const char* devname, int chan);
